@@ -2,7 +2,7 @@
 #'
 #' @details See \url{https://radiant-rstats.github.io/docs/data/visualize.html} for an example in Radiant
 #'
-#' @param dataset Data to plot (data.frame or tibble) 
+#' @param dataset Data to plot (data.frame or tibble)
 #' @param xvar One or more variables to display along the X-axis of the plot
 #' @param yvar Variable to display along the Y-axis of the plot (default = "none")
 #' @param comby Combine yvars in plot (TRUE or FALSE, FALSE is the default)
@@ -23,6 +23,10 @@
 #' @param check Add a regression line ("line"), a loess line ("loess"), or jitter ("jitter") to a scatter plot
 #' @param axes Flip the axes in a plot ("flip") or apply a log transformation (base e) to the y-axis ("log_y") or the x-axis ("log_x")
 #' @param alpha Opacity for plot elements (0 to 1)
+#' @param theme ggplot theme to use (e.g., "theme_gray" or "theme_classic")
+#' @param base_size Base font size to use (default = 11)
+#' @param base_family Base font family to use (e.g., "Times" or "Helvetica")
+#' @param labs Labels to use for plots
 #' @param xlim Set limit for y-axis (e.g., c(0, 1))
 #' @param ylim Set limit for y-axis (e.g., c(0, 1))
 #' @param data_filter Expression used to filter the dataset. This should be a string (e.g., "price > 10000")
@@ -40,7 +44,7 @@
 #' visualize(diamonds, yvar = "price", xvar = c("cut","clarity"),
 #'   type = "line", fun = "max")
 #' visualize(diamonds, yvar = "price", xvar = "carat", type = "scatter",
-#'           size = "table", custom = TRUE) + scale_size(range=c(1,10), guide = "none")
+#'           size = "table", custom = TRUE) + scale_size(range = c(1, 10), guide = "none")
 #' visualize(diamonds, yvar = "price", xvar = "carat", type = "scatter", custom = TRUE) +
 #'   labs(title = "A scatterplot", x = "price in $")
 #' visualize(diamonds, xvar = "price:carat", custom = TRUE) %>%
@@ -55,8 +59,9 @@ visualize <- function(
   facet_row = ".", facet_col = ".", color = "none", fill = "none",
   size = "none", fillcol = "blue", linecol = "black", pointcol = "black",
   bins = 10, smooth = 1, fun = "mean", check = "", axes = "",
-  alpha = 0.5, xlim = NULL, ylim = NULL, data_filter = "", shiny = FALSE,
-  custom = FALSE
+  alpha = 0.5, theme = "theme_gray", base_size = 11, base_family = "",
+  labs = list(), xlim = NULL, ylim = NULL, data_filter = "",
+  shiny = FALSE, custom = FALSE
 ) {
 
   ## inspired by Joe Cheng's ggplot2 browser app http://www.youtube.com/watch?feature=player_embedded&v=o2B5yJeEl1A#!
@@ -171,7 +176,6 @@ visualize <- function(
   }
 
   ## 1 of first level of factor, else 0
-  # if (type == "bar" || type == "scatter" || type == "line") {
   if (type == "bar") {
     isFctY <- "factor" == dc & names(dc) %in% yvar
     if (sum(isFctY)) {
@@ -310,8 +314,6 @@ visualize <- function(
         if (dc[i] == "factor") {
 
           ## make range comparable to bar plot
-          # ymax <- max(dataset[[j]]) %>% {if (. < 0) 0 else .}
-          # ymin <- min(dataset[[j]]) %>% {if (. > 0) 0 else .}
           ymax <- max(0, max(dataset[[j]]))
           ymin <- min(0, min(dataset[[j]]))
           plot_list[[itt]] <- plot_list[[itt]] + ylim(ymin, ymax)
@@ -331,14 +333,14 @@ visualize <- function(
             plot_list[[itt]] <- plot_list[[itt]] +
               stat_summary(
                 fun.data = fun1, na.rm = TRUE, aes(fill = fun[1]),
-                geom = "crossbar", show.legend = FALSE, 
+                geom = "crossbar", show.legend = FALSE,
                 color = linecol[1]
               )
           } else {
             plot_list[[itt]] <- plot_list[[itt]] +
               stat_summary(
                 fun.data = fun1, na.rm = TRUE, aes(fill = fun[1]),
-                geom = "crossbar", show.legend = TRUE, 
+                geom = "crossbar", show.legend = TRUE,
                 color = linecol[1]
               )
 
@@ -351,7 +353,7 @@ visualize <- function(
               plot_list[[itt]] <- plot_list[[itt]] +
                 stat_summary(
                   fun.data = fun2, na.rm = TRUE, aes(fill = fun[2]),
-                  geom = "crossbar", show.legend = FALSE, 
+                  geom = "crossbar", show.legend = FALSE,
                   color = linecol[2]
                 )
             }
@@ -365,7 +367,7 @@ visualize <- function(
               plot_list[[itt]] <- plot_list[[itt]] +
                 stat_summary(
                   fun.data = fun3, na.rm = TRUE, aes(fill = fun[3]),
-                  geom = "crossbar", show.legend = FALSE, 
+                  geom = "crossbar", show.legend = FALSE,
                   color = linecol[3]
                 )
             }
@@ -426,10 +428,9 @@ visualize <- function(
               select_at(.vars = c(tbv, j)) %>%
               na.omit() %>%
               summarise_all(fun)
-              # summarise_all(fun, na.rm = TRUE)
             colnames(tmp)[ncol(tmp)] <- j
             plot_list[[itt]] <- ggplot(tmp, aes_string(x = i, y = j)) + geom_line(aes(group = 1), color = linecol)
-            if (nrow(tmp) < 101) plot_list[[itt]] <- plot_list[[itt]] + geom_point(color = linecol)
+            if (nrow(tmp) < 101) plot_list[[itt]] <- plot_list[[itt]] + geom_point(color = pointcol)
           } else {
             plot_list[[itt]] <- ggplot(dataset, aes_string(x = i, y = j)) + geom_line(color = linecol)
           }
@@ -441,7 +442,6 @@ visualize <- function(
               select_at(.vars = c(tbv, color, j)) %>%
               na.omit() %>%
               summarise_all(fun)
-              # summarise_all(fun, na.rm = TRUE)
             colnames(tmp)[ncol(tmp)] <- j
             plot_list[[itt]] <- ggplot(tmp, aes_string(x = i, y = j, color = color, group = color)) + geom_line()
             if (nrow(tmp) < 101) plot_list[[itt]] <- plot_list[[itt]] + geom_point()
@@ -470,7 +470,6 @@ visualize <- function(
           select_at(.vars = c(tbv, j)) %>%
           na.omit() %>%
           summarise_all(fun)
-          # summarise_all(fun, na.rm = TRUE)
         colnames(tmp)[ncol(tmp)] <- j
 
         if ("sort" %in% axes && facet_row == "." && facet_col == ".") {
@@ -499,7 +498,6 @@ visualize <- function(
         if (dc[i] %in% c("factor", "integer", "date") && nrow(tmp) < nrow(dataset)) {
           if (exists("levs")) {
             if (j %in% names(levs)) {
-              # plot_list[[itt]]$labels$y %<>% paste0(., " (", fun, " of ", ., " == ", levs[j], ")")
               plot_list[[itt]]$labels$y %<>% paste0(., " (", fun, " {", levs[j], "})")
             } else {
               plot_list[[itt]]$labels$y %<>% paste0(., " (", fun, ")")
@@ -519,7 +517,7 @@ visualize <- function(
       for (j in yvar) {
         if (color == "none") {
           plot_list[[itt]] <- ggplot(dataset, aes_string(x = i, y = j)) +
-            geom_boxplot(alpha = alpha, fill = fillcol)
+            geom_boxplot(alpha = alpha, fill = fillcol, outlier.color = pointcol, color = linecol)
         } else {
           plot_list[[itt]] <- ggplot(dataset, aes_string(x = i, y = j, fill = color)) +
             geom_boxplot(alpha = alpha)
@@ -563,10 +561,8 @@ visualize <- function(
       plot_list[[i]] <- plot_list[[i]] + aes_string(fill = fill)
   }
 
-  # if (ylim != "none" && is.numeric(ylim) && length(ylim) == 2) {
   if (!is_empty(ylim, "none") && is.numeric(ylim) && length(ylim) == 2) {
     for (i in 1:length(plot_list))
-      # plot_list[[i]] <- plot_list[[i]] + ylim(ylim[1], ylim[2])
       plot_list[[i]] <- plot_list[[i]] + coord_cartesian(ylim = ylim)
   }
 
@@ -586,8 +582,7 @@ visualize <- function(
       plot_list[[i]] <- plot_list[[i]] +
         sshhr(
           geom_smooth(
-            method = "lm", fill = fillcol, alpha = 0.1, size = .75,
-            linetype = "dashed", color = linecol
+            method = "lm", alpha = 0.2, size = .75, linetype = "dashed"
         )
       )
     }
@@ -598,8 +593,7 @@ visualize <- function(
       plot_list[[i]] <- plot_list[[i]] +
         sshhr(
           geom_smooth(
-            span = smooth, method = "loess", size = .75,
-            linetype = "dotdash", aes(group = 1)
+            span = smooth, method = "loess", alpha = 0.2, size = .75, linetype = "dotdash"
           )
         )
     }
@@ -614,6 +608,22 @@ visualize <- function(
     }
   }
 
+  if (length(labs) > 0) {
+    if (is.list(labs[[1]])) {
+      for (i in 1:length(labs)) {
+        plot_list[[i]] <- plot_list[[i]] + ggplot2::labs(labs[[i]])
+      }
+    } else {
+      plot_list[[1]] <- plot_list[[1]] + ggplot2::labs(labs)
+    }
+  }
+
+  ## setting theme
+  for (i in 1:length(plot_list)) {
+    plot_list[[i]] <- plot_list[[i]] +
+      get(theme)(base_size = ifelse(is.na(base_size), 11, base_size), base_family = base_family)
+  }
+
   if (custom) {
     if (length(plot_list) == 1) {
       return(plot_list[[1]])
