@@ -3,21 +3,22 @@
 #######################################
 
 output$ui_state_load <- renderUI({
-  if (!isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-  # if (isTRUE(getOption("radiant.local", FALSE))) {
+  if (getOption("radiant.shinyFiles", FALSE)) {
     tagList(
-      HTML("</br><label>Load radiant state file (.rda):</label></br>"),
-      actionButton("state_load", "Load", icon = icon("upload"))
+      HTML("<label>Load radiant state file:</label></br>"),
+      shinyFiles::shinyFilesButton(
+        "state_load", "Load", "Load radiant state file",
+        multiple = FALSE, icon = icon("upload")
+      )
     )
   } else {
-    fileInput("state_load", "Load radiant state file (.rda):", accept = ".rda")
+    fileInput("state_load", "Load radiant state file:", accept = ".rda")
   }
 })
 
 make_uploadfile <- function(accept) {
-  if (!isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-  # if (isTRUE(getOption("radiant.local", FALSE))) {
-    actionButton("uploadfile", "Load", icon = icon("upload"))
+  if (getOption("radiant.shinyFiles", FALSE)) {
+    shinyFiles::shinyFilesButton("uploadfile", "Load", "Load data", multiple = TRUE, icon = icon("upload"))
   } else {
     fileInput("uploadfile", NULL, multiple = TRUE, accept = accept)
   }
@@ -54,7 +55,6 @@ output$ui_fileUpload <- renderUI({
 })
 
 output$ui_clipboard_load <- renderUI({
-  # if (isTRUE(getOption("radiant.local", FALSE))) {
   if (Sys.info()["sysname"] != "Linux") {
     actionButton("loadClipData", "Paste", icon = icon("paste"))
   } else {
@@ -75,7 +75,7 @@ output$ui_clipboard_save <- renderUI({
     actionButton("man_save_clip", "Copy data", icon = icon("copy"))
   } else {
     textAreaInput(
-      "man_save_clip_text_area", "Copy-and-paste data below:",
+      "man_save_clip_text_area", "Copy-and-paste data shown below:",
       rows = 5, resize = "vertical",
       value = capture.output(
         write.table(r_data[[input$dataset]], file = "", row.names = FALSE, sep = "\t")
@@ -124,7 +124,8 @@ observeEvent(input$from_global_load, {
       r_info[[paste0(df, "_lcmd")]] <- paste0("# ", r_info[[paste0(df, "_lcmd")]])
     }
     r_info[[paste0(df, "_descr")]] <- attr(r_data[[df]], "description") %>%
-      {if (is.null(.)) "No description provided. Please use Radiant to add an overview of the data in markdown format.\nCheck the 'Add/edit data description' box on the top-left of your screen" else .}
+      {if (is.null(.)) "No description provided. Please use Radiant to add an overview of the data in markdown format.\nCheck the 'Add/edit data description' box on the top-left of your screen" else .} %>%
+      fix_smart()
   }
   updateSelectInput(
     session, "dataset", label = "Datasets:",
@@ -154,21 +155,13 @@ observeEvent(input$to_global_save, {
   )
 })
 
-output$ui_man_state_save <- renderUI({
-  download_button("man_state_save", "Save", ic = "download")
-})
-
-output$ui_man_save_data <- renderUI({
-  download_button("man_save_data", "Save", ic = "download")
-})
-
 output$ui_Manage <- renderUI({
   data_types_in <- c(
-    "rds" = "rds", "rda (rdata)" = "rda", "csv" = "csv",
+    "rds | rda | rdata" = "rds", "csv" = "csv",
     "clipboard" = "clipboard", "examples" = "examples",
     "rda (url)" = "url_rda", "csv (url)" = "url_csv",
     "feather" = "feather", "from global workspace" = "from_global",
-    "radiant state file" = "state" 
+    "radiant state file" = "state"
   )
   data_types_out <- c(
     "rds" = "rds", "rda" = "rda", "csv" = "csv",
@@ -224,7 +217,8 @@ output$ui_Manage <- renderUI({
       conditionalPanel(
         condition = "input.dataType == 'state'",
         uiOutput("ui_state_load"),
-        uiOutput("refreshOnUpload")
+        uiOutput("ui_state_upload"),
+        uiOutput("refreshOnLoad")
       )
     ),
     wellPanel(
@@ -235,8 +229,8 @@ output$ui_Manage <- renderUI({
       ),
       conditionalPanel(
         condition = "input.saveAs == 'state'",
-        HTML("<label>Save radiant state file (.rda):</label><br/>"),
-        uiOutput("ui_man_state_save")
+        HTML("<label>Save radiant state file:</label><br/>"),
+        uiOutput("ui_state_save")
       ),
       conditionalPanel(
         condition = "input.saveAs == 'to_global'",
@@ -246,7 +240,7 @@ output$ui_Manage <- renderUI({
         condition = "input.saveAs != 'clipboard' &&
                      input.saveAs != 'state' &&
                      input.saveAs != 'to_global'",
-        uiOutput("ui_man_save_data")
+        download_button("man_save_data", "Save", ic = "download")
       )
     ),
     wellPanel(
@@ -271,8 +265,9 @@ output$ui_Manage <- renderUI({
 
 ## updating the dataset description
 observeEvent(input$updateDescr, {
-  r_info[[paste0(input$dataset, "_descr")]] <- input$man_data_descr
-  attr(r_data[[input$dataset]], "description") <- input$man_data_descr
+  descr <- fix_smart(input$man_data_descr)
+  r_info[[paste0(input$dataset, "_descr")]] <- descr
+  attr(r_data[[input$dataset]], "description") <- descr
   updateCheckboxInput(
     session = session, "man_add_descr",
     "Add/edit data description", FALSE
@@ -305,12 +300,12 @@ output$man_descr_md <- renderUI({
 ## removing datasets
 output$uiRemoveDataset <- renderUI({
   selectInput(
-    inputId = "removeDataset", 
+    inputId = "removeDataset",
     label = NULL,
-    choices = r_info[["datasetlist"]], 
-    selected = NULL, 
+    choices = r_info[["datasetlist"]],
+    selected = NULL,
     multiple = TRUE,
-    size = length(r_info[["datasetlist"]]), 
+    size = length(r_info[["datasetlist"]]),
     selectize = FALSE
   )
 })
@@ -343,136 +338,133 @@ observeEvent(input$man_save_clip, {
   r_info[[paste0(input$dataset, "_scmd")]] <- glue('save_clip({input$dataset})')
 })
 
-# if (isTRUE(getOption("radiant.local", FALSE))) {
-if (!isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-  observeEvent(input$man_state_save, {
-    path <- rstudioapi::selectFile(
-      caption = "Radiant state file name",
-      path = state_name(full.name = TRUE),
-      filter = "Radiant state file (*.rda)",
-      existing = FALSE
-    )
-
-    if (!is(path, "try-error") && !is_empty(path)) {
-      r_state$radiant_state_name <<- path
-      saveState(path)
-    }
-  })
-} else {
-  output$man_state_save <- downloadHandler(
-    filename = function() {
-      state_name()
-    },
-    content = function(file) {
-      saveState(file)
-    }
-  )
-}
-
 man_save_data <- function(file) {
   ext <- input$saveAs
   robj <- input$dataset
   pp <- suppressMessages(
     radiant.data::parse_path(
-      file, 
-      pdir = getOption("radiant.project_dir", ""), 
-      chr = "\""
+      file,
+      pdir = getOption("radiant.project_dir", ""),
+      chr = "\"",
+      mess = FALSE
     )
   )
-  if (ext == "csv") {
-    readr::write_csv(r_data[[robj]], file)
-    r_info[[paste0(robj, "_scmd")]] <- glue('readr::write_csv({robj}, path = {pp$rpath})')
-  } else {
-    if (!is_empty(input$man_data_descr)) {
-      attr(r_data[[robj]], "description") <- r_info[[paste0(robj, "_descr")]]
-    }
 
-    if (ext == "rds") {
-      readr::write_rds(r_data[[robj]], path = file)
-      r_info[[paste0(robj, "_scmd")]] <- glue('readr::write_rds({robj}, path = {pp$rpath})')
-    } else if (ext == "feather") {
-      ## temporary workaround until PR goes through https://stackoverflow.com/a/47898172/1974918
-      # feather::write_feather(tmp[[robj]], file)
-      # radiant.data::write_feather(tmp[[robj]], file, description = attr(tmp[[robj]], "description"))
-      feather::write_feather(r_data[[robj]], file)
-      r_info[[paste0(robj, "_scmd")]] <- glue('feather::write_feather({robj}, path = {pp$rpath})')
+  withProgress(message = "Saving ...", value = 1, {
+    if (ext == "csv") {
+      readr::write_csv(r_data[[robj]], file)
+      r_info[[paste0(robj, "_scmd")]] <- glue('readr::write_csv({robj}, path = {pp$rpath})')
     } else {
-      save(list = robj, file = file, envir = r_data)
-      r_info[[paste0(robj, "_scmd")]] <- glue('save({robj}, file = {pp$rpath})')
-    }
-  }
-}
+      if (!is_empty(input$man_data_descr)) {
+        attr(r_data[[robj]], "description") <- fix_smart(r_info[[paste0(robj, "_descr")]])
+      }
 
-if (!isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-# if (isTRUE(getOption("radiant.local", FALSE))) {
-  observeEvent(input$man_save_data, {
-    path <- rstudioapi::selectFile(
-      caption = "Save data",
-      path = file.path(
-        getOption("radiant.launch_dir", "~"),
-        paste0(input$dataset, ".", input$saveAs)
-      ),
-      filter = paste0("Save data (*.", input$saveAs, ")"),
-      existing = FALSE
-    )
-    if (!is(path, "try-error") && !is_empty(path)) {
-      man_save_data(path)
+      if (ext == "rds") {
+        readr::write_rds(r_data[[robj]], path = file)
+        r_info[[paste0(robj, "_scmd")]] <- glue('readr::write_rds({robj}, path = {pp$rpath})')
+      } else if (ext == "feather") {
+        ## temporary workaround until PR goes through https://stackoverflow.com/a/47898172/1974918
+        # feather::write_feather(tmp[[robj]], file)
+        # radiant.data::write_feather(tmp[[robj]], file, description = attr(tmp[[robj]], "description"))
+        feather::write_feather(r_data[[robj]], file)
+        r_info[[paste0(robj, "_scmd")]] <- glue('feather::write_feather({robj}, path = {pp$rpath})')
+      } else {
+        save(list = robj, file = file, envir = r_data)
+        r_info[[paste0(robj, "_scmd")]] <- glue('save({robj}, file = {pp$rpath})')
+      }
     }
   })
-} else {
-  output$man_save_data <- downloadHandler(
-    filename = function() {
-      paste0(input$dataset, ".", input$saveAs)
-    },
-    content = function(file) {
-      man_save_data(file)
-    }
-  )
 }
 
-observeEvent(input$uploadfile, {
-
-  if (!isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-  # if (isTRUE(getOption("radiant.local", FALSE))) {
-    if (input$dataType == "csv") {
-      caption <- "Select .csv"
-      filter <- "Select .csv or similar (*)"
+if (getOption("radiant.shinyFiles", FALSE)) {
+  sf_filetypes <- function() {
+    if (length(input$dataType) == 0) {
+      ""
+    } else if (input$dataType == "csv") {
+      c("csv", "tsv")
     } else if (input$dataType %in% c("rda", "rds")) {
-      caption <- "Select .rds or .rda"
-      filter <- "Select .rds or .rds (*)"
+      c("rda", "rds", "rdata")
     } else if (input$dataType == "feather") {
-      caption <- "Select .feather"
-      filter <- "Select .feather (*.feather)"
+      "feather"
+    } else {
+      ""
     }
+  }
 
-    path <- rstudioapi::selectFile(
-      caption = caption,
-      filter = filter,
-      path = getOption("radiant.launch_dir")
-    )
-    if (is(path, "try-error") || is_empty(path)) return()
-    inFile <- data.frame(
-      name = basename(path),
-      datapath = path,
-      stringsAsFactors = FALSE
-    )
+  sf_uploadfile <- shinyFiles::shinyFileChoose(
+    input = input,
+    id = "uploadfile",
+    session = session,
+    roots = sf_volumes,
+    filetype = sf_filetypes
+  )
+
+  sf_state_load <- shinyFiles::shinyFileChoose(
+    input = input,
+    id = "state_load",
+    session = session,
+    roots = sf_volumes,
+    filetype = c("rda", "state.rda")
+  )
+} else {
+  output$ui_state_save <- renderUI({
+    download_button("state_save", "Save", ic = "download")
+  })
+}
+
+state_name_dlh <- function() state_name(full.name = FALSE)
+
+download_handler(
+  id = "state_save",
+  label = "Save",
+  fun = saveState,
+  fn = function() state_name_dlh() %>% sans_ext(),
+  type = function() state_name_dlh() %>% {if (grepl("\\.state\\.rda", .)) "state.rda" else tools::file_ext(.)},
+  btn = "button",
+  caption = "Save radiant state file"
+)
+
+## need to set suspendWhenHidden to FALSE so that the href for the
+## download handler is set and keyboard shortcuts will work
+## see https://shiny.rstudio.com/reference/shiny/0.11/outputOptions.html
+## see https://stackoverflow.com/questions/48117501/click-link-in-navbar-menu
+## https://stackoverflow.com/questions/3871358/get-all-the-href-attributes-of-a-web-site
+outputOptions(output, "ui_state_save", suspendWhenHidden = FALSE)
+
+download_handler(
+  id = "man_save_data",
+  fun = man_save_data,
+  fn = function() input$dataset,
+  type = function() input$saveAs,
+  caption = "Save data",
+  btn = "button",
+  label = "Save"
+)
+
+observeEvent(input$uploadfile, {
+  if (getOption("radiant.shinyFiles", FALSE)) {
+    if (is.integer(input$uploadfile)) return()
+    inFile <- shinyFiles::parseFilePaths(sf_volumes, input$uploadfile)
+    if (nrow(inFile) == 0) return()
   } else {
     inFile <- input$uploadfile
   }
 
   ## iterating through the files to upload
-  for (i in 1:(dim(inFile)[1])) {
-    load_user_data(
-      inFile[i, "name"],
-      inFile[i, "datapath"],
-      input$dataType,
-      header = input$man_header,
-      man_str_as_factor = input$man_str_as_factor,
-      sep = input$man_sep,
-      dec = input$man_dec,
-      n_max = input$man_n_max
-    )
-  }
+  withProgress(message = "Loading ...", value = 1, {
+    for (i in 1:(dim(inFile)[1])) {
+      load_user_data(
+        as.character(inFile[i, "name"]),
+        as.character(inFile[i, "datapath"]),
+        input$dataType,
+        header = input$man_header,
+        man_str_as_factor = input$man_str_as_factor,
+        sep = input$man_sep,
+        dec = input$man_dec,
+        n_max = input$man_n_max
+      )
+    }
+  })
 
   updateSelectInput(
     session, "dataset",
@@ -490,11 +482,11 @@ observeEvent(input$url_rda_load, {
   con <- try(curl::curl_download(url_rda, tempfile()), silent = TRUE)
 
   cmd <- NULL
-  if (is(con, "try-error")) {
+  if (inherits(con, "try-error")) {
     upload_error_handler(objname, "#### There was an error loading the r-data file from the provided url.")
   } else {
     robjname <- try(load(con), silent = TRUE)
-    if (is(robjname, "try-error")) {
+    if (inherits(robjname, "try-error")) {
       upload_error_handler(objname, "#### There was an error loading the r-data file from the provided url.")
     } else {
       if (length(robjname) > 1) {
@@ -515,7 +507,7 @@ observeEvent(input$url_rda_load, {
     shiny::makeReactiveBinding(objname, env = r_data)
   }
   r_info[["datasetlist"]] <- c(objname, r_info[["datasetlist"]]) %>% unique()
-  r_info[[paste0(objname, "_descr")]] <- attr(r_data[[objname]], "description")
+  r_info[[paste0(objname, "_descr")]] <- fix_smart(attr(r_data[[objname]], "description"))
   r_info[[paste0(objname, "_lcmd")]] <- cmd
 
   updateSelectInput(
@@ -536,7 +528,7 @@ observeEvent(input$url_csv_load, {
   ret <- try(curl::curl_download(url_csv, con), silent = TRUE)
 
   cmd <- NULL
-  if (is(ret, "try-error")) {
+  if (inherits(ret, "try-error")) {
     upload_error_handler(objname, "#### There was an error loading the csv file from the provided url")
   } else {
     dataset <- load_csv(
@@ -562,18 +554,19 @@ observeEvent(input$url_csv_load, {
       if (delim == "," && dec == "." && col_names == FALSE) {
         cmd <- glue('
           {objname} <- readr::read_csv(
-            "{url_csv}", 
+            "{url_csv}",
             n_max = {n_max}
-          )') 
+          )')
       } else {
         cmd <- glue('
           {objname} <- readr::read_delim(
-            "{url_csv}", 
+            "{url_csv}",
             delim = "{delim}", col_names = {col_names}, n_max = {n_max},
             locale = readr::locale(decimal_mark = "{dec}", grouping_mark = "{delim}")
-          )') 
+          )')
       }
-      if (saf) cmd <- glue('{cmd} %>% to_fct()')
+      cmd <- paste0(cmd, " %>%\n  fix_names()")
+      if (saf) cmd <- paste0(cmd, " %>%\n  to_fct()")
       cmd <- glue('{cmd}\nregister("{objname}")')
     }
   }
@@ -582,7 +575,7 @@ observeEvent(input$url_csv_load, {
     shiny::makeReactiveBinding(objname, env = r_data)
   }
   r_info[["datasetlist"]] <- c(objname, r_info[["datasetlist"]]) %>% unique()
-  r_info[[paste0(objname, "_descr")]] <- attr(r_data[[objname]], "description")
+  r_info[[paste0(objname, "_descr")]] <- fix_smart(attr(r_data[[objname]], "description"))
   r_info[[paste0(objname, "_lcmd")]] <- cmd
 
   updateSelectInput(
@@ -605,8 +598,8 @@ observeEvent(input$loadExampleData, {
     }
     if (is.data.frame(get(item, envir = r_data))) {
       r_info[["datasetlist"]] <- c(item, r_info[["datasetlist"]]) %>% unique()
-      r_info[[paste0(item, "_descr")]] <- attr(r_data[[item]], "description")
-      r_info[[paste0(item, "_lcmd")]] <- glue('{item} <- data({item}, package = "{exdat[i, "Package"]}") %>% get()\nregister("{item}")')
+      r_info[[paste0(item, "_descr")]] <- fix_smart(attr(r_data[[item]], "description"))
+      r_info[[paste0(item, "_lcmd")]] <- glue('{item} <- data({item}, package = "{exdat[i, "Package"]}", envir = environment()) %>% get()\nregister("{item}")')
     } else {
       r_info[["dtree_list"]] <- c(item, r_info[["dtree_list"]]) %>% unique()
     }
@@ -626,7 +619,7 @@ observeEvent(input$loadClipData, {
   ## reading data from clipboard
   objname <- "from_clipboard"
   dataset <- radiant.data::load_clip("\t", input$load_cdata)
-  if (is(dataset, "try-error") || length(dim(dataset)) < 2 || nrow(dataset) == 0) {
+  if (inherits(dataset, "try-error") || length(dim(dataset)) < 2 || nrow(dataset) == 0) {
     ret <- "#### Data in clipboard was not well formatted. Try exporting the data to csv format"
     upload_error_handler(objname, ret)
   } else {
@@ -636,7 +629,7 @@ observeEvent(input$loadClipData, {
     fn <- radiant.data::fix_names(cn)
     if (!identical(cn, fn)) {
       colnames(dataset) <- fn
-      cmd <- paste0(cmd, "%>% fix_names()")
+      cmd <- paste0(cmd, " %>% fix_names()")
     }
     r_data[[objname]] <- dataset
     r_info[[paste0(objname, "_lcmd")]] <- glue('{cmd}\nregister("{objname}")')
@@ -647,9 +640,9 @@ observeEvent(input$loadClipData, {
   r_info[[paste0(objname, "_descr")]] <- ret
   r_info[["datasetlist"]] <- c(objname, r_info[["datasetlist"]]) %>% unique()
   updateSelectInput(
-    session, "dataset", 
+    session, "dataset",
     label = "Datasets:",
-    choices = r_info[["datasetlist"]], 
+    choices = r_info[["datasetlist"]],
     selected = objname
   )
 })
@@ -657,23 +650,43 @@ observeEvent(input$loadClipData, {
 #######################################
 # Load previous state
 #######################################
-output$refreshOnUpload <- renderUI({
-  req(input$state_load)
-  if (!isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-  # if (isTRUE(getOption("radiant.local", FALSE))) {
-    path <- rstudioapi::selectFile(
-      caption = "Select .rda",
-      filter = "Select .rda (*.rda)",
-      path = getOption("radiant.launch_dir")
-    )
-    if (is(path, "try-error") || is_empty(path)) return()
-    sname <- basename(path)
+output$refreshOnLoad <- renderUI({
+  # req(input$state_load)
+  req(pressed(input$state_load) || pressed(input$state_upload))
+
+  if (pressed(input$state_load)) {
+    if (getOption("radiant.shinyFiles", FALSE)) {
+      if (is.integer(input$state_load)) return()
+      path <- shinyFiles::parseFilePaths(sf_volumes, input$state_load)
+      if (inherits(path, "try-error") || is_empty(path$datapath)) return()
+      path <- path$datapath
+      sname <- basename(path)
+    } else {
+      path <- input$state_load$datapath
+      sname <- input$state_load$name
+    }
   } else {
-    path <- input$state_load$datapath
-    sname <- input$state_load$name
+    path <- input$state_upload$datapath
+    sname <- input$state_upload$name
   }
 
-  if (is_empty(path)) return(invisible())
+  if (is_empty(path)) {
+    invisible()
+  } else {
+    withProgress(message = "Loading state file", value = 1, {
+      refreshOnLoad(path, sname)
+    })
+    ## Joe Cheng: https://groups.google.com/forum/#!topic/shiny-discuss/Olr8m0JwMTo
+    tags$script("window.location.reload();")
+  }
+})
+
+output$ui_state_upload <- renderUI({
+  fileInput("state_upload", "Upload radiant state file:", accept = ".rda")
+})
+
+refreshOnLoad <- function(path, sname) {
+
   tmpEnv <- new.env(parent = emptyenv())
   load(path, envir = tmpEnv)
 
@@ -684,8 +697,8 @@ output$refreshOnUpload <- renderUI({
       modalDialog(
         title = "Restore radiant state failed",
         span(
-          "Unable to restore radiant state from the selected file. 
-          Choose another state file or select 'rda' from the 'Load 
+          "Unable to restore radiant state from the selected file.
+          Choose another state file or select 'rds | rda | rdata' from the 'Load
           data of type' dropdown to load an R-data file and try again"
         ),
         footer = modalButton("OK"),
@@ -735,19 +748,16 @@ output$refreshOnUpload <- renderUI({
   )
 
   rm(tmpEnv)
-
-  ## Joe Cheng: https://groups.google.com/forum/#!topic/shiny-discuss/Olr8m0JwMTo
-  tags$script("window.location.reload();")
-})
-
+}
 
 ## need to set suspendWhenHidden to FALSE so that the href for the
 ## these outputs is available on startup and keyboard shortcuts will work
 ## see https://shiny.rstudio.com/reference/shiny/0.11/outputOptions.html
 ## see https://stackoverflow.com/questions/48117501/click-link-in-navbar-menu
 ## https://stackoverflow.com/questions/3871358/get-all-the-href-attributes-of-a-web-site
-outputOptions(output, "refreshOnUpload", suspendWhenHidden = FALSE)
+outputOptions(output, "refreshOnLoad", suspendWhenHidden = FALSE)
 outputOptions(output, "ui_state_load", suspendWhenHidden = FALSE)
+outputOptions(output, "ui_state_upload", suspendWhenHidden = FALSE)
 
 #######################################
 # Save state
@@ -766,7 +776,7 @@ saveState <- function(filename) {
 }
 
 observeEvent(input$renameButton, {
-  req(!is_empty(input$data_rename)) 
+  req(!is_empty(input$data_rename))
   req(!identical(input$dataset, input$data_rename))
   ## use lobstr::object_size to see that the size of the list doesn't change
   ## when you assign a list element another name
@@ -780,8 +790,8 @@ observeEvent(input$renameButton, {
   lcmd <- r_info[[paste0(input$dataset, "_lcmd")]] %>%
     sub(glue('^{input$dataset} <- '), glue('{input$data_rename} <- '), .) %>%
     sub(
-      glue('register\\("{input$dataset}"\\)'), 
-      glue('register\\("{input$data_rename}"\\)'), 
+      glue('register\\("{input$dataset}"\\)'),
+      glue('register\\("{input$data_rename}"\\)'),
       .
     )
   r_info[[paste0(input$data_rename, "_lcmd")]] <- lcmd
@@ -795,8 +805,8 @@ observeEvent(input$renameButton, {
   r_info[["datasetlist"]] %<>% unique()
 
   updateSelectInput(
-    session, "dataset", 
-    label = "Datasets:", 
+    session, "dataset",
+    label = "Datasets:",
     choices = r_info[["datasetlist"]],
     selected = input$data_rename
   )
@@ -806,10 +816,10 @@ output$ui_datasets <- renderUI({
   ## Drop-down selection of active dataset
   tagList(
     selectInput(
-      inputId = "dataset", 
-      label = "Datasets:", 
+      inputId = "dataset",
+      label = "Datasets:",
       choices = r_info[["datasetlist"]],
-      selected = state_init("dataset"), 
+      selected = state_init("dataset"),
       multiple = FALSE
     ),
     conditionalPanel(
@@ -842,25 +852,24 @@ output$uiRename <- renderUI({
 })
 
 output$man_example <- renderText({
-  if (is.null(.get_data())) return()
+  req(!is.null(r_data[[input$dataset]]))
   ## Show only the first 10 (or 20) rows
   show_data_snippet(nshow = 10)
 })
 
 output$man_str <- renderPrint({
-  req(is.data.frame(.get_data()))
+  req(is.data.frame(r_data[[input$dataset]]))
   str(r_data[[input$dataset]])
 })
 
-output$man_summary <- renderPrint({
-  req(is.data.frame(.get_data()))
-  get_summary(r_data[[input$dataset]])
+output$man_summary <- renderUI({
+  req(is.data.frame(r_data[[input$dataset]]))
+  summarytools::dfSummary(r_data[[input$dataset]], style = 'grid', plain.ascii = FALSE, graph.magnif = 0.85) %>%
+    print(method = 'render', omit.headings = TRUE)
 })
 
-
 man_show_log <- reactive({
-  if (!isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-  # if (isTRUE(getOption("radiant.local", FALSE))) {
+  if (getOption("radiant.shinyFiles", FALSE)) {
     lcmd <- r_info[[paste0(input$dataset, "_lcmd")]]
     cmd <- ""
     if (!is_empty(lcmd)) {
@@ -878,7 +887,7 @@ man_show_log <- reactive({
 
 output$ui_man_log <- renderUI({
   tags$textarea(
-    isolate(man_show_log()), 
+    isolate(man_show_log()),
     id = "man_log",
     type = "text",
     rows = 5,
@@ -892,9 +901,6 @@ output$ui_man_log <- renderUI({
 
 observe({
   input$man_show_log
-  if (isTRUE(input$man_show_log) && isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-    man_show_log_modal()
-  }
   updateTextAreaInput(session, "man_log", value = man_show_log())
 })
 
@@ -903,16 +909,13 @@ man_show_log_modal <- function() {
     modalDialog(
       title = "Generating R-code to load and save data",
       span(
-        "R-code to load and save data is not generated and reported 
-         when using radiant with an (external) web browser (e.g., Chrome).
-         This is due to the fact that the web browser's file dialog does 
-         not provide file path information for security reasons.", 
-        br(), br(), 
-        "To generate R-code to load and save data, start Radiant in an 
-         Rstudio Window or in the Rstudio Viewer (see Rstudio Addins drop 
-         down). Users on Windows or Linux should upgrade Rstudio using  
-         the following link. ", 
-         a("https://www.rstudio.com/products/rstudio/download/preview/")
+        "R-code to load and save data is not generated and reported
+         when using radiant from (shiny) server. This is due to the
+         fact that the web browser's file dialog does not provide
+         file path information for security reasons.",
+        br(), br(),
+        "To generate R-code to load and save data, start Radiant from
+         Rstudio."
       ),
       footer = modalButton("OK"),
       size = "s",
@@ -922,8 +925,7 @@ man_show_log_modal <- function() {
 }
 
 observeEvent(input$manage_report, {
-  if (!isTRUE(getOption("radiant.launch", "browser") == "browser")) {
-  # if (isTRUE(getOption("radiant.local", FALSE))) {
+  if (getOption("radiant.shinyFiles", FALSE)) {
     update_report(cmd = man_show_log(), outputs = NULL, figs = FALSE)
   } else {
     man_show_log_modal()
