@@ -39,16 +39,14 @@ pvt_plot_args <- as.list(if (exists("plot.pivotr")) {
   formals(plot.pivotr)
 } else {
   formals(radiant.data:::plot.pivotr)
-} )
+})
 
 ## list of function inputs selected by user
 pvt_plot_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
   for (i in names(pvt_plot_args))
     pvt_plot_args[[i]] <- input[[paste0("pvt_", i)]]
-
   pvt_plot_args$type <- ifelse(isTRUE(pvt_plot_args$type), "fill", "dodge")
-
   pvt_plot_args
 })
 
@@ -185,6 +183,7 @@ output$ui_Pivotr <- renderUI({
       uiOutput("ui_pvt_run")
     ),
     wellPanel(
+      # actionLink("pvt_clear", "Clear settings", icon = icon("refresh"), style="color:black"),
       uiOutput("ui_pvt_cvars"),
       uiOutput("ui_pvt_nvar"),
       conditionalPanel("input.pvt_nvar != 'None'", uiOutput("ui_pvt_fun")),
@@ -268,8 +267,7 @@ observeEvent(input$pivotr_search_columns, {
 })
 
 observeEvent(input$pivotr_state, {
-  r_state$pivotr_state <<-
-    if (is.null(input$pivotr_state)) list() else input$pivotr_state
+  r_state$pivotr_state <<- if (is.null(input$pivotr_state)) list() else input$pivotr_state
 })
 
 output$pivotr <- DT::renderDataTable({
@@ -312,7 +310,7 @@ output$pivotr_chi2 <- renderPrint({
 
 dl_pivot_tab <- function(file) {
   dat <- try(.pivotr(), silent = TRUE)
-  if (is(dat, "try-error") || is.null(dat)) {
+  if (inherits(dat, "try-error") || is.null(dat)) {
     write.csv(tibble::tibble("Data" = "[Empty]"), file, row.names = FALSE)
   } else {
     rows <- isolate(r_info[["pvt_rows"]])
@@ -322,7 +320,7 @@ dl_pivot_tab <- function(file) {
   }
 }
 
-download_handler(id = "dl_pivot_tab", fun = dl_pivot_tab, fn = paste0(input$dataset, "_pivot.csv"))
+download_handler(id = "dl_pivot_tab", fun = dl_pivot_tab, fn = function() paste0(input$dataset, "_pivot"))
 
 pvt_plot_width <- function() 750
 
@@ -377,7 +375,7 @@ observeEvent(input$pivotr_rows_all, {
 })
 
 .plot_pivot <- eventReactive({
-  c(input$pvt_run, input$pvt_flip, input$pvt_type, input$pvt_perc)
+  c(input$pvt_run, input$pvt_flip, input$pvt_type, input$pvt_perc, req(input$pivotr_state))
 }, {
   pvt <- .pivotr()
   req(pvt)
@@ -397,10 +395,15 @@ output$plot_pivot <- renderPlot({
   .plot_pivot()
 }, width = pvt_plot_width, height = pvt_plot_height, res = 96)
 
+# observeEvent(input$pvt_clear, {
+#   r_state$pivotr_state <<- list()
+#   updateCheckboxInput(session = session, inputId = "show_filter", value = FALSE)
+# })
+
 observeEvent(input$pvt_store, {
   req(input$pvt_name)
   dat <- try(.pivotr(), silent = TRUE)
-  if (is(dat, "try-error") || is.null(dat)) return()
+  if (inherits(dat, "try-error") || is.null(dat)) return()
   name <- input$pvt_name
   rows <- input$pivotr_rows_all
   dat$tab %<>% {if (is.null(rows)) . else .[rows, , drop = FALSE]}
@@ -483,8 +486,9 @@ observeEvent(input$pivotr_report, {
 download_handler(
   id = "dlp_pivot",
   fun = download_handler_plot,
-  fn = paste0(input$dataset, "_pivot.png"),
-  caption = "Download pivot plot",
+  fn = function() paste0(input$dataset, "_pivot"),
+  type = "png",
+  caption = "Save pivot plot",
   plot = .plot_pivot,
   width = pvt_plot_width,
   height = pvt_plot_height
