@@ -78,10 +78,18 @@ $(document).keydown(function(event) {
 });
 
 $(function(){
+  $("#state_save_link").on('click', function(e){
+    e.preventDefault();
+    $("#state_save").trigger('click');
+  });
   $("#state_load_link").on('click', function(e){
     e.preventDefault();
     $("#state_load").trigger('click');
   });
+  $("#state_upload_link").on('click', function(e){
+    e.preventDefault();
+    $("#state_upload").trigger('click');
+  });
 });
 
 // from https://stackoverflow.com/a/33251536/1974918 by Dean Attali
